/*
 * This file is part of the Owl Positioning System (OwlPS).
 * OwlPS is a project of the University of Franche-Comté
 * (Université de Franche-Comté), France.
 */


#ifndef _OWLPS_POSITIONING_MOBILE_HH_
#define _OWLPS_POSITIONING_MOBILE_HH_

#include "wifidevice.hh"

#include <ostream>

#define MOBILE_DEFAULT_ANTENNA_GAIN 2

/// \brief Represents a mobile \link WifiDevice Wi-Fi device\endlink
/// that can be localised
class Mobile: public WifiDevice
{
public:
  Mobile(const std::string &_ip_addr = "",
         const std::string &_mac_addr = "",
         const float &_antenna_gain = MOBILE_DEFAULT_ANTENNA_GAIN,
         const float &_trx_power = WIFIDEVICE_DEFAULT_TRX_POWER):
    WifiDevice(_ip_addr, _mac_addr, _antenna_gain, _trx_power) {}

  Mobile(const WifiDevice &wd):
    WifiDevice(wd) {}

  Mobile(const Mobile &m):
    WifiDevice(m) {}

  ~Mobile(void) {}

  /** @name Operators */
  //@{
  Mobile& operator=(const Mobile &m) ;
  bool operator==(const Mobile &m) const ;
  bool operator!=(const Mobile &m) const ;
  //@}

  /// Displays a Mobile
  friend std::ostream &operator<<(std::ostream &os, const Mobile &m) ;
} ;



/* *** Operators *** */


inline bool Mobile::operator!=(const Mobile &m) const
{
  return !(*this == m) ;
}



#endif // _OWLPS_POSITIONING_MOBILE_HH_
