/*
 * This file is part of the Owl Positioning System (OwlPS).
 * OwlPS is a project of the University of Franche-Comté
 * (Université de Franche-Comté), France.
 */


#ifndef _OWLPS_POSITIONING_OUTPUTUDPSOCKET_HH_
#define _OWLPS_POSITIONING_OUTPUTUDPSOCKET_HH_

#include "outputnetworksocket.hh"

/// Sends results to a remote host by UDP
/**
 * The results are sent through an UDP socket as a CSV string value.
 * The format used is the same as in OutputCSV, and is documented in
 * ResultList::to_csv().
 */
class OutputUDPSocket: public OutputNetworkSocket
{
protected:
  /** @name Operations */
  //@{
  /// Initialises the socket
  bool init_socket(void) ;
  /// Sends a string through the socket
  bool send_data(const std::string &data) const ;
  //@}

public:
  OutputUDPSocket(const std::string &_remote_host,
                  const uint_fast16_t _remote_port) ;
} ;



#endif // _OWLPS_POSITIONING_OUTPUTUDPSOCKET_HH_
