/*
 * This file is part of the Owl Positioning System (OwlPS).
 * OwlPS is a project of the University of Franche-Comté
 * (Université de Franche-Comté), France.
 */


#include "resultlist.hh"
#include "request.hh"
#include "mobile.hh"

#include <sstream>

using namespace std ;



/* *** Constructors *** */


ResultList::~ResultList()
{
  results.clear() ;
}



/* *** Operators *** */


ResultList& ResultList::operator=(const ResultList &source)
{
  if (this == &source)
    return *this ;

  request = source.request ;
  results = source.results ;

  return *this ;
}


bool ResultList::operator==(const ResultList &source) const
{
  return
    request == source.request &&
    results == source.results ;
}



/* *** Conversion accessors *** */


/**
 * This function creates a CSV string from the Result's data.
 *
 * The format used is the following:
 *   Mobile_MAC;Request_type;Timestamp;[Algorithm_1];…;[Algorithm_n]
 *
 * The CSV format for the [Algorithm_i] strings is documented in
 * Result::to_csv().
 *
 * @return The results as a CSV string, \em without a trailing '\\n'.
 */
const string ResultList::to_csv() const
{
  ostringstream csv_line ;

  if (request != NULL)
    {
      if (request->get_mobile() != NULL)
        csv_line << request->get_mobile()->get_mac_addr() ;
      csv_line
          << ';' << static_cast<uint_fast16_t>(request->get_type())
          << ';' << request->get_time_sent() ;
    }
  else
    csv_line << ";;;" ;

  for (vector<Result>::const_iterator r = results.begin() ;
       r != results.end() ; ++r)
    csv_line << ';' << r->to_csv() ;

  return csv_line.str() ;
}



ostream& operator<<(ostream &os, const ResultList &r)
{
  if (r.request == NULL)
    os << "For an unknown request:\n" ;
  else
    os << "For the following request: " << *(r.request) << '\n' ;

  vector<Result>::const_iterator res ;
  for (res = r.results.begin() ; res != r.results.end() ; ++res)
    os << *res << '\n' ;

  return os ;
}
