/*
 * This file is part of the Owl Positioning System (OwlPS).
 * OwlPS is a project of the University of Franche-Comté
 * (Université de Franche-Comté), France.
 */


#ifndef _OWLPS_POSITIONING_TOPOLOGYREADERCSV_HH_
#define _OWLPS_POSITIONING_TOPOLOGYREADERCSV_HH_

class Point3D ;

#include "csvfilereader.hh"

#include <string>

/// \brief Reads and registers to the Stock Area and Waypoint lists
/// from CSV files
/**
 * CSV format for areas is:
 *   Building name;Room name;X1;Y1;Z1;X2;Y2;Z2
 *
 * CSV format for waypoints is:
 *   X;Y;Z;Building name #1[;Building name #2[…[;Building name \#n]]]
 */
class TopologyReaderCSV
{
protected:
  CSVFileReader areas_file ;
  CSVFileReader waypoints_file ;

  void read_topology(void) ;
  void process_area_line(void) ;
  void process_waypoint_line(void) ;

public:
  TopologyReaderCSV(const std::string &areas_file_name,
                    const std::string &waypoints_file_name) ;

  ~TopologyReaderCSV(void) {}
} ;

#endif // _OWLPS_POSITIONING_TOPOLOGYREADERCSV_HH_
