/*
 * This file is part of the Owl Positioning System (OwlPS).
 * OwlPS is a project of the University of Franche-Comté
 * (Université de Franche-Comté), France.
 *
 * This is the header file of OwlPS UDP-to-HTTP.
 */


#ifndef _OWLPS_UDP_TO_HTTP_H_
#define _OWLPS_UDP_TO_HTTP_H_

#include <owlps-resultreader.h>

#define TCP_PORT 8080
#define NB_CONNECTIONS 1
#define CLIENT_MESSAGE_STRLEN 2500

#define CLIENT_REQUEST_STRLEN 21
#define SIMPLE_RESULTS_ID 1
#define SIMPLE_RESULTS_REQUEST "ReadSimpleResults"
#define SIMPLE_RESULTS_ANSWER "SimpleResults"
#define RESULTS_ID 2
#define RESULTS_REQUEST "ReadResults"
#define RESULTS_ANSWER "Results"

#ifndef OWLPS_VERSION
# define OWLPS_VERSION "unknown version"
#endif // OWLPS_VERSION

#define ANSWER_HDR                                 \
  "HTTP/1.1 200 OK\n"                              \
  "Date: Sat, 01 Jan 0001 00:00:01 GMT\n"          \
  "Server: OwlPS UDP-to-HTTP ["OWLPS_VERSION"]\n"  \
  "Access-Control-Allow-Origin: *\n"               \
  "Connection: close\n"                            \
  "Content-Type: text/html\n"                      \
  "\n"
#define ANSWER_HDR_STRLEN strlen(ANSWER_HDR)


typedef struct _results_list
{
  owl_result *result ;
  struct _results_list *next ;
} results_list ;


int receive_udp(void) ;
void store_result(owl_result *result) ;
int init_tcp_socket(void) ;
void* tcp_server(void *NULL_value) ;
int
extract_request_from_message(char client_request[CLIENT_REQUEST_STRLEN],
                             char *client_message) ;
void prepare_answer(int request_id) ;
void realloc_answer(size_t new_size) ;
void free_results_list(void) ;


#endif // _OWLPS_UDP_TO_HTTP_H_
